==> pymimir-0.12.10.tar.gz: pymimir-0.12.10/src/graphs/algorithms/color_refinement.cpp <==
/*
 * Copyright (C) 2023 Dominik Drexler and Simon Stahlberg
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "mimir/graphs/algorithms/color_refinement.hpp"

namespace mimir::graphs::color_refinement
{

/* CertificateImpl */
CertificateImpl::CertificateImpl(AbstractColorCompressionFunction c, CompressionFunction f) : m_c(std::move(c)), m_f(f.begin(), f.end()) {}

const CertificateImpl::AbstractColorCompressionFunction& CertificateImpl::get_abstract_color_compression_function() const { return m_c; }

const CertificateImpl::CanonicalCompressionFunction& CertificateImpl::get_canonical_compression_function() const { return m_f; }

bool operator==(const CertificateImpl& lhs, const CertificateImpl& rhs) { return loki::EqualTo<CertificateImpl>()(lhs, rhs); }

std::ostream& operator<<(std::ostream& out, const CertificateImpl& element)
{
    out << "CertificateColorRefinement(" << "abstract_color_compression_function=";
    mimir::operator<<(out, element.get_abstract_color_compression_function());
    out << ", " << "canonical_compression_function=";
    mimir::operator<<(out, element.get_canonical_compression_function());
    out << ")";
    return out;
}

}

==> pymimir-0.12.13.tar.gz: pymimir-0.12.13/src/graphs/algorithms/color_refinement.cpp <==
/*
 * Copyright (C) 2023 Dominik Drexler and Simon Stahlberg
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "mimir/graphs/algorithms/color_refinement.hpp"

namespace mimir::graphs::color_refinement
{

/* CertificateImpl */
CertificateImpl::CertificateImpl(ColorCompressionFunction c, CompressionFunction f) : m_c(std::move(c)), m_f(f.begin(), f.end()) {}

const CertificateImpl::ColorCompressionFunction& CertificateImpl::get_abstract_color_compression_function() const { return m_c; }

const CertificateImpl::CanonicalCompressionFunction& CertificateImpl::get_canonical_compression_function() const { return m_f; }

bool operator==(const CertificateImpl& lhs, const CertificateImpl& rhs) { return loki::EqualTo<CertificateImpl>()(lhs, rhs); }

std::ostream& operator<<(std::ostream& out, const CertificateImpl& element)
{
    out << "CertificateColorRefinement(" << "abstract_color_compression_function=";
    mimir::operator<<(out, element.get_abstract_color_compression_function());
    out << ", " << "canonical_compression_function=";
    mimir::operator<<(out, element.get_canonical_compression_function());
    out << ")";
    return out;
}

}
